@@ -46,7 +46,7 @@ function restart(&$goiprow,$len,$msg)
 	global $db;
 	global $port;
 	global $re_ask_timer;
-	$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status!='LOGOUT' and  goip.id=$goiprow[id]");
+	$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status='LOGIN' and  goip.id=$goiprow[id]");
 	$rs=$db->fetch_array($query);
 	//echo "SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status!='LOGOUT' and goip.id=$goiprow[id]". "restart: $rs[name] !!!<br>";
 	if($rs[0]){
@@ -71,7 +71,7 @@ function restart(&$goiprow,$len,$msg)
 		for($i=0;$i<3;$i++){
 			//echo "check:$i";
 			$read=array($goiprow[sock]);
-			$err=socket_select($read, $write = NULL, $except = NULL, 5);
+			$err=socket_select($read, $write, $except, 5);
 			if($err>0){
 				//echo "11213134";
 				if(($n=@socket_recvfrom($goiprow[sock],$buf,1024,0,$ip,$port1))==false){
@@ -164,7 +164,7 @@ function restart(&$goiprow,$len,$msg)
 				echo ("sendto error:". socket_strerror($socket));
 			for($i=0;$i<3;$i++){
 				$read=array($socket);
-				$err=socket_select($read, $write = NULL, $except = NULL, 5);
+				$err=socket_select($read, $write, $except, 5);
 				if($err>0){		
 					if(($n=@socket_recvfrom($socket,$buf,1024,0,$ip,$port))==false){
 						//echo("recvform error".socket_strerror($ret)."<br>");
@@ -526,10 +526,12 @@ function startdo($db, $tels,$sendid, $goipid=0){
 		global $endless_send;
 		global $re_ask_timer;
 
+		session_write_close();
+
 		$query=$db->query("SELECT send_page_jump_enable FROM system WHERE 1 ");
 		$sys_rs=$db->fetch_array($query);
 		
-		if($sys_rs['send_page_jump_enable']==1){
+		if($_REQUEST['not_jump']!=1 && $sys_rs['send_page_jump_enable']==1){
 			$i=0;
 			$sqlv="insert into sends (messageid,userid,telnum,provider,recvid,recvlev,time,msg,total) values";
 			foreach($tels as $provname => $provtels){
@@ -580,7 +582,7 @@ function startdo($db, $tels,$sendid, $goipid=0){
 				}
 				$goiprow['sock']=$socket;
 				$goiprow['time']=time();//計時
-				if($goiprow[alive] != 1 || $goiprow[gsm_status] == 'LOGOUT'){
+				if($goiprow[alive] != 1 || $goiprow[gsm_status] != 'LOGIN'){
 					$goiprow['timer']=$re_ask_timer;
                                 	$goiprow['send']="RMSG";
 					$goiprow['messageid']=$sendid+($goiprow[id] << 16);
@@ -599,7 +601,7 @@ function startdo($db, $tels,$sendid, $goipid=0){
 					echo ("sendto error");
 				for($i=0;$i<3;$i++){
 					$read=array($socket);
-					$err=socket_select($read, $write = NULL, $except = NULL, 5);
+					$err=socket_select($read, $write, $except, 5);
 					if($err>0){		
 						if(($n=@socket_recvfrom($socket,$buf,1024,0,$ip,$port1))==false){
 							//echo("recvform error".socket_strerror($ret)."<br>");
@@ -639,7 +641,7 @@ function startdo($db, $tels,$sendid, $goipid=0){
 			flush();
 			if(count($read)==0)
 				break;
-			$err=socket_select($read, $write = NULL, $except = NULL, $timeout);
+			$err=socket_select($read, $write, $except, $timeout);
 			//echo "select:$err <br>";
 			if($err===false)
 				echo "select error!";
