@@ -45,7 +45,7 @@ function restart(&$goiprow,$len,$msg)
 	global $db;
 	global $port;
 	global $re_ask_timer;
-	$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status!='LOGOUT' and  goip.id=$goiprow[id]");
+	$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status='LOGIN' and  goip.id=$goiprow[id]");
 	$rs=$db->fetch_array($query);
 	//echo "SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status!='LOGOUT' and goip.id=$goiprow[id]". "restart: $rs[name] !!!<br>";
 	if($rs[0]){
@@ -70,7 +70,7 @@ function restart(&$goiprow,$len,$msg)
 		for($i=0;$i<3;$i++){
 			//echo "check:$i";
 			$read=array($goiprow[sock]);
-			$err=socket_select($read, $write = NULL, $except = NULL, 5);
+			$err=socket_select($read, $write, $except, 5);
 			if($err>0){
 				//echo "11213134";
 				if(($n=@socket_recvfrom($goiprow[sock],$buf,1024,0,$ip,$port1))==false){
@@ -162,7 +162,7 @@ function restart(&$goiprow,$len,$msg)
 				echo ("sendto error:". socket_strerror($socket));
 			for($i=0;$i<3;$i++){
 				$read=array($socket);
-				$err=socket_select($read, $write = NULL, $except = NULL, 5);
+				$err=socket_select($read, $write, $except, 5);
 				if($err>0){		
 					if(($n=@socket_recvfrom($socket,$buf,1024,0,$ip,$port))==false){
 						//echo("recvform error".socket_strerror($ret)."<br>");
@@ -401,7 +401,7 @@ elseif(isset($_POST['alltype'])) {//向全部人發送
 		if($_GET[id])
 			$db->query("update message set type=2, recv=$jr, recv1=$jr1, recv2=$jr1, msg='$_POST[Memo]', userid=$_SESSION[goip_userid],total='$total',crontime=$crontime where id=$_GET[id]");
 		else 
-			$db->query("INSERT INTO message (type,msg,userid,crontime,recv,recv1,recv2,total) VALUES (2, '$_POST[Memo]', $_SESSION[goip_userid],$crontime,$jr,$jr1,$jr2,'$total')");	
+			$db->query("INSERT INTO message (type,msg,userid,total,crontime,recv,recv1,recv2) VALUES (2, '$_POST[Memo]', $_SESSION[goip_userid],'$total',$crontime,$jr,$jr1,$jr2)");	
 		do_cron($db,$crontime,$goipcronport);
 		exit;
 	}
@@ -525,6 +525,7 @@ function startdo($db, $tels,$sendid, $goipid=0){
 		global $endless_send;
 		global $re_ask_timer;
 
+		session_write_close();
                 $query=$db->query("SELECT send_page_jump_enable FROM system WHERE 1 ");
                 $sys_rs=$db->fetch_array($query);
                 
@@ -582,7 +583,7 @@ function startdo($db, $tels,$sendid, $goipid=0){
 					echo "GoIP Line($goiprow[name]) remain count is down<br>";
 					continue;
 				}
-				if($goiprow[alive] != 1 || $goiprow[gsm_status] == 'LOGOUT'){
+				if($goiprow[alive] != 1 || $goiprow[gsm_status] != 'LOGIN'){
 					$goiprow['timer']=$re_ask_timer;
                                 	$goiprow['send']="RMSG";
 					$goiprow['messageid']=$sendid+($goiprow[id] << 16);
@@ -601,7 +602,7 @@ function startdo($db, $tels,$sendid, $goipid=0){
 					echo ("sendto error");
 				for($i=0;$i<3;$i++){
 					$read=array($socket);
-					$err=socket_select($read, $write = NULL, $except = NULL, 5);
+					$err=socket_select($read, $write, $except, 5);
 					if($err>0){		
 						if(($n=@socket_recvfrom($socket,$buf,1024,0,$ip,$port1))==false){
 							//echo("recvform error".socket_strerror($ret)."<br>");
@@ -640,7 +641,7 @@ function startdo($db, $tels,$sendid, $goipid=0){
 			flush();
 			if(count($read)==0)
 				break;
-			$err=socket_select($read, $write = NULL, $except = NULL, $timeout);
+			$err=socket_select($read, $write, $except, $timeout);
 			//echo "select:$err <br>";
 			if($err===false)
 				echo "select error!";
