@@ -53,7 +53,7 @@ function restart(&$goiprow,$len,$msg)
         global $db;
         global $port;
 	global $re_ask_timer;
-        $query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status!='LOGOUT' and  goip.id=$goiprow[id]");
+        $query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status='LOGIN' and  goip.id=$goiprow[id]");
         $rs=$db->fetch_array($query);
         //echo "SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status!='LOGOUT' and goip.id=$goiprow[id]". "restart: $rs[name] !!!<br>";
         if($rs[0]){
@@ -195,7 +195,7 @@ function startdo($db, $tels, $sendid, $msg, $len, $goipid=0){
 					echo "GoIP Line($goiprow[name]) remain count is down<br>";
 					continue;
 				}
-                                if($goiprow[alive] != 1 || $goiprow[gsm_status] == 'LOGOUT'){
+                                if($goiprow[alive] != 1 || $goiprow[gsm_status] != 'LOGIN'){
                                         $goiprow['timer']=$re_ask_timer;
                                         $goiprow['send']="RMSG";
                                         $goiprow['messageid']=$sendid+($goiprow[id] << 16)+$goiprow['time']%10000;
@@ -750,6 +750,7 @@ function startdo($db, $tels, $sendid, $msg, $len, $goipid=0){
 	echo "total: $totalnum <br>";
 	//die;
 	//print_r($tels);
+	session_write_close();
 	startdo($db, $tels, $sendid, $msg, $len, $goipid);
 
 ?>
